==> e107-0.7.20.tbz: www/e107/e107_languages/English/lan_email.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_email.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
if (!defined("PAGE_NAME")) { define("PAGE_NAME", "Email"); }

define("LAN_EMAIL_1", "From:");
define("LAN_EMAIL_2", "IP address of sender:");
define("LAN_EMAIL_3", "Emailed item from ");
define("LAN_EMAIL_4", "Send Email");
define("LAN_EMAIL_5", "Email item to a friend");
define("LAN_EMAIL_6", "I thought you might be interested in this item from");
define("LAN_EMAIL_7", "email to someone");
define("LAN_EMAIL_8", "Comment");
define("LAN_EMAIL_9", "Sorry - unable to send email");
define("LAN_EMAIL_10", "Mail sent to");
define("LAN_EMAIL_11", "Email sent");
define("LAN_EMAIL_12", "Error");
define("LAN_EMAIL_13", "Email article to a friend");
define("LAN_EMAIL_14", "Email news_item to a friend");
define("LAN_EMAIL_15", "Username: ");
define("LAN_EMAIL_106", "That doesn't appear to be a valid email address");
define("LAN_EMAIL_185", "Send Article");
define("LAN_EMAIL_186", "Send News Item");
define("LAN_EMAIL_187", "Email address to send to");
define("LAN_EMAIL_188", "I thought you might be interested in this news story from");
define("LAN_EMAIL_189", "I thought you might be interested in this article from");
define("LAN_EMAIL_190", "Enter visible code");

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/lan_email.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_email.php $
|     $Revision: 11678 $
|     $Id: lan_email.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
if (!defined("PAGE_NAME")) { define("PAGE_NAME", "Email"); }

define("LAN_EMAIL_1", "From:");
define("LAN_EMAIL_2", "IP address of sender:");
define("LAN_EMAIL_3", "Emailed item from ");
define("LAN_EMAIL_4", "Send Email");
define("LAN_EMAIL_5", "Email item to a friend");
define("LAN_EMAIL_6", "I thought you might be interested in this item from");
define("LAN_EMAIL_7", "email to someone");
define("LAN_EMAIL_8", "Comment");
define("LAN_EMAIL_9", "Sorry - unable to send email");
define("LAN_EMAIL_10", "Mail sent to");
define("LAN_EMAIL_11", "Email sent");
define("LAN_EMAIL_12", "Error");
define("LAN_EMAIL_13", "Email article to a friend");
define("LAN_EMAIL_14", "Email news_item to a friend");
define("LAN_EMAIL_15", "Username: ");
define("LAN_EMAIL_106", "That doesn't appear to be a valid email address");
define("LAN_EMAIL_185", "Send Article");
define("LAN_EMAIL_186", "Send News Item");
define("LAN_EMAIL_187", "Email address to send to");
define("LAN_EMAIL_188", "I thought you might be interested in this news story from");
define("LAN_EMAIL_189", "I thought you might be interested in this article from");
define("LAN_EMAIL_190", "Enter visible code");

?>
